#!/bin/bash

# Green Unicorn Setup Script v0.1
WEBSITE_NAME=@@WEBSITE@@
NAME="${WEBSITE_NAME}_app"
DJANGODIR=/opt/site/django/${WEBSITE_NAME}
SOCKFILE=/opt/site/run/gunicorn.sock
USER=@@WEBUSER@@
GROUP=@@WEBUSER@@
NUM_CPUS=$(grep ^processor /proc/cpuinfo | wc -l)
NUM_WORKERS=$(( 1 + 2 * $NUM_CPUS ))
DJANGO_SETTINGS_MODULE=${WEBSITE_NAME}.settings
DJANGO_WSGI_MODULE=${WEBSITE_NAME}.wsgi

echo "Starting gunicorn as $(whoami) with $NUM_WORKERS workers for ${DJANGODIR}"

# Activate the virtual environment
. /opt/site/venv/bin/activate

# Setup Django environment
cd ${DJANGODIR}
export DJANGO_SETTINGS_MODULE=$DJANGO_SETTINGS_MODULE
export PYTHONPATH=$DJANGO_SETTINGS_MODULE:$PYTHONPATH

# Create the run directory, if necessary.
RUNDIR=$(dirname $0)
test -d  || mkdir -p $RUNDIR

# Start the Django Unicorn daemon.
exec /opt/site/venv/bin/gunicorn ${DJANGO_WSGI_MODULE}:application \
    --name $NAME \
    --workers $NUM_WORKERS \
    --user=$USER \
    --group=$GROUP \
    --bind=unix:$SOCKFILE
